@@ -16,11 +16,6 @@ class AdsorptionGraphComparator(object):
     graph automorphism by color refinement, a cheap label match is used to 
     reject graphs that are impossible to be automorphic.
 
-    The graphs (nx.Graph objects) can be quite costly to obtain every time 
-    a graph is required (and disk intensive if saved), thus it makes sense 
-    to get the graph along with e.g. the potential energy and save it in 
-    atoms.info['data']['graph'].
-
     Parameters
     ----------
     adsorption_sites : acat.adsorption_sites.ClusterAdsorptionSites object \
@@ -61,50 +56,42 @@ class AdsorptionGraphComparator(object):
         self.hmax = hmax
         self.dmax = dmax
         self.kwargs = kwargs
+        self.kwargs['return_adj_matrix'] = False
         self.comp = WLGraphComparator(hmax=self.hmax)
 
     def looks_like(self, a1, a2):
-        isocheck = False
-        if ('data' in a1.info and 'graph' in a1.info['data']) and (
-        'data' in a2.info and 'graph' in a2.info['data']):
-            isocheck = True
-            G1 = a1.info['data']['graph']
-            G2 = a2.info['data']['graph']
+        sas = deepcopy(self.adsorption_sites)        
+ 
+        if hasattr(sas, 'surface'):
+            sas.update(a1, update_composition=self.composition_effect)
+            sac1 = SlabAdsorbateCoverage(a1, sas, subtract_height=
+                                         self.subtract_height, 
+                                         label_occupied_sites=True, 
+                                         dmax=self.dmax)
+            sas.update(a2, update_composition=self.composition_effect)
+            sac2 = SlabAdsorbateCoverage(a2, sas, subtract_height=
+                                         self.subtract_height, 
+                                         label_occupied_sites=True, 
+                                         dmax=self.dmax)
         else:
-            sas = deepcopy(self.adsorption_sites)        
+            sas.update(a1, update_composition=self.composition_effect)
+            sac1 = ClusterAdsorbateCoverage(a1, sas, subtract_height=
+                                            self.subtract_height, 
+                                            label_occupied_sites=True,
+                                            dmax=self.dmax)
+            sas.update(a2, update_composition=self.composition_effect)
+            sac2 = ClusterAdsorbateCoverage(a2, sas, subtract_height=
+                                            self.subtract_height, 
+                                            label_occupied_sites=True,
+                                            dmax=self.dmax)
+        labs1 = sac1.get_occupied_labels(fragmentation=self.kwargs.get(
+                                         'fragmentation', True))
+        labs2 = sac2.get_occupied_labels(fragmentation=self.kwargs.get(
+                                         'fragmentation', True))       
  
-            if hasattr(sas, 'surface'):
-                sas.update(a1, update_composition=self.composition_effect)
-                sac1 = SlabAdsorbateCoverage(a1, sas, subtract_height=
-                                             self.subtract_height, 
-                                             label_occupied_sites=True, 
-                                             dmax=self.dmax)
-                sas.update(a2, update_composition=self.composition_effect)
-                sac2 = SlabAdsorbateCoverage(a2, sas, subtract_height=
-                                             self.subtract_height, 
-                                             label_occupied_sites=True, 
-                                             dmax=self.dmax)
-            else:
-                sas.update(a1, update_composition=self.composition_effect)
-                sac1 = ClusterAdsorbateCoverage(a1, sas, subtract_height=
-                                                self.subtract_height, 
-                                                label_occupied_sites=True,
-                                                dmax=self.dmax)
-                sas.update(a2, update_composition=self.composition_effect)
-                sac2 = ClusterAdsorbateCoverage(a2, sas, subtract_height=
-                                                self.subtract_height, 
-                                                label_occupied_sites=True,
-                                                dmax=self.dmax)
-            labs1 = sac1.get_occupied_labels(fragmentation=self.kwargs.get(
-                                             'fragmentation', True))
-            labs2 = sac2.get_occupied_labels(fragmentation=self.kwargs.get(
-                                             'fragmentation', True))       
- 
-            if labs1 == labs2:
-                isocheck = True 
-                G1 = sac1.get_graph(self.kwargs)
-                G2 = sac2.get_graph(self.kwargs)
-        if isocheck:
+        if labs1 == labs2:
+            G1 = sac1.get_graph(**self.kwargs)
+            G2 = sac2.get_graph(**self.kwargs)
             if self.comp.looks_like(G1, G2):
                 return True
 
@@ -120,8 +107,8 @@ class WLGraphComparator(object):
 
     The graphs (nx.Graph objects) can be quite costly to obtain every time 
     a graph is required (and disk intensive if saved), thus it makes sense 
-    to get the graph along with e.g. the potential energy and save it in 
-    atoms.info['data']['graph'].
+    to get the adjacency matrix along with e.g. the potential energy and 
+    save it in atoms.info['data']['adj_matrix'].
 
     Parameters
     ----------
@@ -142,13 +129,33 @@ class WLGraphComparator(object):
         self.tol = tol
 
     def looks_like(self, a1, a2):
+        """a1, a2 can be eithr 2 ase.Atoms objects or 2 networkx graphs."""
+
         if isinstance(a1, Atoms) and isinstance(a2, Atoms):
-            if ('data' in a1.info and 'graph' in a1.info['data']) and (
-            'data' in a2.info and 'graph' in a2.info['data']):
-                a1 = a1.info['data']['graph']
-                a2 = a2.info['data']['graph']
-        d1 = WLGraphComparator.get_label_dict(a1, self.hmax, self.dx)
-        d2 = WLGraphComparator.get_label_dict(a2, self.hmax, self.dx)
+            if ('data' in a1.info and 'adj_matrix' in a1.info['data']) and (
+            'data' in a2.info and 'adj_matrix' in a2.info['data']):
+                A1 = a1.info['data']['adj_matrix']
+                G1 = nx.from_numpy_matrix(A1)
+                A2 = a2.info['data']['adj_matrix']
+                G2 = nx.from_numpy_matrix(A2)
+            else:
+                nblist1 = neighbor_shell_list(a1, dx=dx, neighbor_number=1,
+                                         mic=(True in a1.pbc))
+                A1 = get_adj_matrix(nblist1)
+                G1 = nx.from_numpy_matrix(A1)
+                nblist2 = neighbor_shell_list(a2, dx=dx, neighbor_number=1,
+                                         mic=(True in a2.pbc))
+                A2 = get_adj_matrix(nblist2)
+                G2 = nx.from_numpy_matrix(A2)
+            s1 = a1.symbols
+            s2 = a2.symbols
+        else:
+            G1, G2 = a1, a2
+            s1 = np.asarray([G1.nodes[n]['symbol'] for n in G1.nodes()], dtype=object)
+            s2 = np.asarray([G2.nodes[n]['symbol'] for n in G2.nodes()], dtype=object)
+
+        d1 = WLGraphComparator.get_label_dict(G1, s1, self.hmax, self.dx)
+        d2 = WLGraphComparator.get_label_dict(G2, s2, self.hmax, self.dx)
         d12 = {k: [d[k] if k in d else 0 for d in (d1, d2)] 
                for k in set(d1.keys()) | set(d2.keys())}
         X12 = np.asarray(list(d12.values()))
@@ -161,21 +168,9 @@ class WLGraphComparator(object):
         return abs(k12 - (k11 * k22)**0.5) <= self.tol 
 
     @classmethod
-    def get_label_dict(cls, G, hmax, dx):                                                        
+    def get_label_dict(cls, G, symbols, hmax, dx):                                                        
         d = {}
-        if isinstance(G, Atoms):
-            atoms = G.copy()
-            symbols = atoms.symbols
-            nblist = neighbor_shell_list(atoms, dx=dx, neighbor_number=1, 
-                                         mic=(True in atoms.pbc))                     
-            A = get_adj_matrix(nblist)
-            N = len(A)
-            G = nx.from_numpy_matrix(A)
-        else:
-            N = G.number_of_nodes()
-            symbols = np.asarray([G.nodes[i]['symbol'] for i in range(N)], 
-                                 dtype=object)
-
+        N = G.number_of_nodes()
         nnlabs, neighbors = {}, {}
         isolates = []
         for i in range(N):
