@@ -86,8 +86,7 @@ class GroupSubstitute(Mutation):
                         found = True
                         break
                 if not found:
-                    return None, '{1} not possible in {0} due to broken symmetry'.format(
-                                  f.info['confid'], self.descriptor)                     
+                    return None                 
             else:
                 groups = self.groups
         if self.elements is None:
@@ -120,6 +119,10 @@ class GroupSubstitute(Mutation):
         f = parents[0]
 
         indi = self.substitute(f)
+        if indi is None:
+            return None, '{0} not possible in {1} due to broken symmetry'.format( 
+                          self.descriptor, f.info['confid'])                     
+
         indi = self.initialize_individual(f, indi)
         if 'groups' in f.info['data']:
             indi.info['data']['groups'] = f.info['data']['groups']
@@ -178,8 +181,8 @@ class GroupPermutation(Mutation):
 
         # Return None if there is only one atomic type
         if diffatoms == 1:
-            return None, '{1} not possible in {0}'.format(f.info['confid'],
-                                                          self.descriptor)
+            return None, '{0} not possible in {1}'.format(self.descriptor,
+                                                          f.info['confid'])
         indi = self.initialize_individual(f)
         indi.info['data']['parents'] = [f.info['confid']]
         if self.groups is None:
@@ -198,8 +201,8 @@ class GroupPermutation(Mutation):
                         found = True
                         break
                 if not found:
-                    return None, '{1} not possible in {0} due to broken symmetry'.format(
-                                  f.info['confid'], self.descriptor)                     
+                    return None, '{0} not possible in {1} due to broken symmetry'.format(
+                                  self.descriptor, f.info['confid'])                     
             else:
                 groups = self.groups
             if 'data' in f.info:
@@ -413,8 +416,7 @@ class AdsorbateGroupSubstitute(Mutation):
                         found = True
                         break
                 if not found:
-                    return None, '{1} not possible in {0} due to broken symmetry'.format(
-                                  atoms.info['confid'], self.descriptor)                     
+                    return None 
             else:
                 groups = self.site_groups
 
@@ -506,6 +508,10 @@ class AdsorbateGroupSubstitute(Mutation):
     def get_new_individual(self, parents):
         f = parents[0]
         indi = self.substitute(f)
+        if indi is None:
+            return None, '{0} not possible in {1} due to broken symmetry'.format(
+                         self.descriptor, f.info['confid'])                 
+
         indi = self.initialize_individual(f, indi) 
         if 'groups' in f.info['data']:
             indi.info['data']['groups'] = f.info['data']['groups']
@@ -648,8 +654,8 @@ class AdsorbateGroupPermutation(Mutation):
                         found = True
                         break
                 if not found:
-                    return None, '{1} not possible in {0} due to broken symmetry'.format(
-                                  f.info['confid'], self.descriptor)                     
+                    return None, '{0} not possible in {1} due to broken symmetry'.format(
+                                  self.descriptor, f.info['confid'])                     
             else:
                 site_groups = self.site_groups
             if 'groups' in f.info['data']:
@@ -657,8 +663,8 @@ class AdsorbateGroupPermutation(Mutation):
 
         # Return None if there is only one adsorbate (vacancy) type
         if set([hsl[g[0]]['fragment'] for g in site_groups]) == 1:
-            return None, '{1} not possible in {0}'.format(f.info['confid'],
-                                                          self.descriptor)
+            return None, '{0} not possible in {1}'.format(self.descriptor,
+                                                          f.info['confid'])
         for _ in range(self.num_muts):
             AdsorbateGroupPermutation.mutate(f, site_groups, self.heights, sas, 
                                              hsl, self.remove_site_shells, 
@@ -813,8 +819,8 @@ class GroupCrossover(Crossover):
                         found = True
                         break
                 if not found:
-                    return None, '{1} not possible in {0} due to broken symmetry'.format(
-                                  f.info['confid'], self.descriptor)                      
+                    return None, '{0} not possible in {1} due to broken symmetry'.format(
+                                  self.descriptor, f.info['confid'])                      
             else:
                 groups = self.groups.copy()
         if self.elements is None:
