@@ -96,7 +96,7 @@ class MultitaskPopulation(Population):
         else:
             return self.exp_prefactor ** (-rfit - 1)
 
-    def update(self, new_cand):
+    def update(self, new_cand=None):
         """The update method in Population will add to the end of
         the population, that can't be used here since the fitness
         will potentially change for all candidates when new are added,
@@ -105,69 +105,70 @@ class MultitaskPopulation(Population):
         The maximum gain dynamic niching (MGDN) algorithm is executed.
         """
 
-        # Update the upper envelope
-        prev_max_scores = self.max_scores.copy()
-        gained_ids = []
-        for i, a in enumerate(new_cand):
-            scores = a.info['data']['raw_scores']
-            gained_niches = np.argwhere(scores > self.max_scores)
-            if gained_niches.size != 0:
-                self.max_scores[gained_niches] = scores[gained_niches]
-                gained_ids.append(i)
-
-        # Update the array that records the niche dominating other gained niches
-        # with the requirements of: 1. contributes to the updated upper envelope;
-        # 2. maximum in gain compared to the previous upper envelope
-        first_generation = np.any(prev_max_scores == np.NINF)
-        for i in gained_ids:
-            scores = new_cand[i].info['data']['raw_scores']
-            maxed_niches = np.argwhere(scores == self.max_scores)
-            if maxed_niches.size != 0:
-                if first_generation:
-                    dominating_niche = int(max(maxed_niches, key=lambda x: scores[x]))
-                else:
-                    dominating_niche = int(max(maxed_niches, key=lambda x:
-                                               scores[x] - prev_max_scores[x]))
-                self.dominating_niches[maxed_niches] = dominating_niche
-
-        # Caculate the effective fitness and assign a niche for each new candidate
-        for i in range(len(new_cand)):
-            scores = new_cand[i].info['data']['raw_scores']
-            min_loss_niche = np.argmax(scores - self.max_scores)
-            dominating_niche = self.dominating_niches[min_loss_niche]
-            f_eff = float(np.around(scores[min_loss_niche] - 
-                          self.max_scores[min_loss_niche], 8))
-            new_cand[i].info['key_value_pairs']['raw_score'] = f_eff
-            new_cand[i].info['key_value_pairs']['dominating_niche'] = dominating_niche
-            new_cand[i].info['data']['niches'] = np.argwhere(
-                self.dominating_niches==dominating_niche).flatten() 
-
-        # Update the fitness of all previously-relaxed candidates if fitness     
-        # is gained at any niche from the new generation (niche migration)
-        updated_cand = []
-        if gained_ids and len(self.pop) > 0:
-            # Update the database        
-            prev_cand = self.dc.get_all_relaxed_candidates()
-            del_ids = [] 
-            for a in prev_cand:
+        if new_cand is not None:
+            # Update the upper envelope
+            prev_max_scores = self.max_scores.copy()
+            gained_ids = []
+            for i, a in enumerate(new_cand):
                 scores = a.info['data']['raw_scores']
+                gained_niches = np.argwhere(scores > self.max_scores)
+                if gained_niches.size != 0:
+                    self.max_scores[gained_niches] = scores[gained_niches]
+                    gained_ids.append(i)
+ 
+            # Update the array that records the niche dominating other gained niches
+            # with the requirements of: 1. contributes to the updated upper envelope;
+            # 2. maximum in gain compared to the previous upper envelope
+            first_generation = np.any(prev_max_scores == np.NINF)
+            for i in gained_ids:
+                scores = new_cand[i].info['data']['raw_scores']
+                maxed_niches = np.argwhere(scores == self.max_scores)
+                if maxed_niches.size != 0:
+                    if first_generation:
+                        dominating_niche = int(max(maxed_niches, key=lambda x: scores[x]))
+                    else:
+                        dominating_niche = int(max(maxed_niches, key=lambda x:
+                                                   scores[x] - prev_max_scores[x]))
+                    self.dominating_niches[maxed_niches] = dominating_niche
+ 
+            # Caculate the effective fitness and assign a niche for each new candidate
+            for i in range(len(new_cand)):
+                scores = new_cand[i].info['data']['raw_scores']
                 min_loss_niche = np.argmax(scores - self.max_scores)
                 dominating_niche = self.dominating_niches[min_loss_niche]
                 f_eff = float(np.around(scores[min_loss_niche] - 
                               self.max_scores[min_loss_niche], 8))
-                a.info['key_value_pairs']['raw_score'] = f_eff
-                a.info['key_value_pairs']['dominating_niche'] = dominating_niche
-                a.info['data']['niches'] = np.argwhere(
+                new_cand[i].info['key_value_pairs']['raw_score'] = f_eff
+                new_cand[i].info['key_value_pairs']['dominating_niche'] = dominating_niche
+                new_cand[i].info['data']['niches'] = np.argwhere(
                     self.dominating_niches==dominating_niche).flatten() 
-                updated_cand.append(a)
-                gaid = a.info['confid']
-                del_ids.append(gaid)
-            self.dc.c.delete(del_ids)
-            self.rep_no_gain = 0
-        else:
-            self.rep_no_gain += 1
+ 
+            # Update the fitness of all previously-relaxed candidates if fitness     
+            # is gained at any niche from the new generation (niche migration)
+            updated_cand = []
+            if gained_ids and len(self.pop) > 0:
+                # Update the database        
+                prev_cand = self.dc.get_all_relaxed_candidates()
+                del_ids = [] 
+                for a in prev_cand:
+                    scores = a.info['data']['raw_scores']
+                    min_loss_niche = np.argmax(scores - self.max_scores)
+                    dominating_niche = self.dominating_niches[min_loss_niche]
+                    f_eff = float(np.around(scores[min_loss_niche] - 
+                                  self.max_scores[min_loss_niche], 8))
+                    a.info['key_value_pairs']['raw_score'] = f_eff
+                    a.info['key_value_pairs']['dominating_niche'] = dominating_niche
+                    a.info['data']['niches'] = np.argwhere(
+                        self.dominating_niches==dominating_niche).flatten() 
+                    updated_cand.append(a)
+                    gaid = a.info['confid']
+                    del_ids.append(gaid)
+                self.dc.c.delete(del_ids)
+                self.rep_no_gain = 0
+            else:
+                self.rep_no_gain += 1
+            self.dc.add_more_relaxed_candidates(updated_cand + new_cand)
 
-        self.dc.add_more_relaxed_candidates(updated_cand + new_cand)
         self.pop = []            
         self.__initialize_pop__()
         
@@ -246,9 +247,9 @@ class MultitaskPopulation(Population):
         return (c1.copy(), c2.copy())
 
 
-class MultitaskGenerationRepetitionConvergence(Convergence):                      
-    """Returns True if the latest finished population is stagnated 
-    (no fitness gain in any task) for number_of_generations.
+class MultitaskRepetitionConvergence(Convergence):                      
+    """Returns True if the latest finished population has no fitness 
+    gain in any task for number_of_generations.
 
     Parameters
     ----------
