@@ -441,8 +441,8 @@ class RandomSlabPermutation(SlabOperator):
                 allowed_indices = [idxs for idxs in self.allowed_indices if 
                                    len(set(f0[idxs].get_chemical_symbols())) > 1]
                 if not allowed_indices:
-                    return None, '{1} not possible in {0}'.format(f0.info['confid'],
-                                                                  self.descriptor)
+                    return None, '{0} not possible in {1}'.format(self.descriptor,
+                                                                  f0.info['confid'])
                 self.allowed_indices = random.choice(allowed_indices)
             f = f0[self.allowed_indices]
 
@@ -454,8 +454,8 @@ class RandomSlabPermutation(SlabOperator):
             else:
                 f = f0[self.allowed_indices]
             if len(set(f.get_chemical_symbols())) == 1:
-                return None, '{1} not possible in {0}'.format(f.info['confid'],
-                                                              self.descriptor)
+                return None, '{0} not possible in {1}'.format(self.descriptor,
+                                                              f.info['confid'])
         indi = self.initialize_individual(f, f)
         fail = True
         while fail:
